@@ -14,7 +14,7 @@ from pydantic import BaseModel, Field
 from langchain_core.tools import ToolException
 
 from codemie_tools.base.codemie_tool import CodeMieTool
-from codemie_tools.project_management.jira.tools_vars import GENERIC_JIRA_TOOL
+from codemie_tools.project_management.jira.tools_vars import GENERIC_JIRA_TOOL, get_jira_tool_description
 from codemie_tools.project_management.jira.utils import validate_jira_creds
 from codemie_tools.base.utils import clean_json_string
 
@@ -128,7 +128,7 @@ def process_search_response(jira_url, response, payload_params: Dict[str, Any] =
     for issue in json_response.get('issues', []):
         processed_issues.append(process_issue(jira_url, issue, payload_params))
 
-    return str(processed_issues)
+    return f"Issues: {processed_issues}", f"Total: {json_response.get('total', 0)}"
 
 
 class GenericJiraIssueTool(CodeMieTool):
@@ -159,7 +159,8 @@ class GenericJiraIssueTool(CodeMieTool):
             method="GET",
             path=relative_url,
             params=payload_params,
-            advanced_mode=True
+            advanced_mode=True,
+            headers={"content-type": "application/json"},
         )
         self.jira.raise_for_status(response)
         if re.match(self.issue_search_pattern, relative_url):
@@ -500,4 +501,9 @@ class GenericJiraIssueTool(CodeMieTool):
         else:
             # If the URL does not start with the Jira base URL, return it as is
             relative_file_path = file_url
-        return relative_file_path
\ No newline at end of file
+        return relative_file_path
+    
+
+class GenericJiraCloudIssueTool(GenericJiraIssueTool):
+    issue_search_pattern: str = r'/rest/api/3/search/jql'
+    description: str = get_jira_tool_description(api_version=3) or ""
